# Icestudio collections manager
[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]
[![License][license-image]][license-url]

Tools to manage [Icestudio](https://github.com/FPGAwars) collections.

## Install

```bash
pip install icm
```

## Commands

|  Command   | Description |
|:----------:|:-----------:|
| [create](https://github.com/FPGAwars/icm/wiki#icm-create) | Create a collection structure. |
| [update](https://github.com/FPGAwars/icm/wiki#icm-update) | Update docs and translation. |
| [validate](https://github.com/FPGAwars/icm/wiki#icm-validate) | Validate a collection. |

### Testing

```bash
pip install tox
```

```bash
tox
```

## Authors

* [Jesús Arroyo Torrens](https://github.com/Jesus89)

## License

Licensed under [GPLv2](http://opensource.org/licenses/GPL-2.0).

<!-- Badges -->
[pypi-image]: https://img.shields.io/pypi/v/icm
[pypi-url]: https://pypi.org/project/icm/
[build-image]: https://github.com/FPGAwars/icm/actions/workflows/build.yml/badge.svg
[build-url]: https://github.com/FPGAwars/icm/actions/workflows/build.yml
[license-image]: http://img.shields.io/:license-gpl-blue.svg
[license-url]: (http://opensource.org/licenses/GPL-2.0)